@@ -13,6 +13,7 @@ OC.L10N.register(
     "Allow editing" : "Дазволіць рэдагаванне",
     "Select" : "Select",
     "Title" : "Title",
-    "Link" : "Link"
+    "Link" : "Link",
+    "Folder" : "Folder"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
