@@ -4,6 +4,7 @@ OC.L10N.register(
     "Bookmarks" : "סימניות",
     "No file provided for import" : "לא סופק קובץ לייבוא",
     "Unsupported file type for import" : "סוג הקובץ לייבוא אינו נתמך",
+    "Bookmarks shared by %s" : "סימניות שמשותפות על ידי %s",
     "A Bookmark manager for Nextcloud" : "מנהל סימניות ל־Nextcloud",
     "Select bookmark" : "בחירת סימנייה",
     "Details" : "פרטים",
@@ -15,16 +16,25 @@ OC.L10N.register(
     "No bookmarks here" : "אין כאן סימניות",
     "Try changing your query or add some using the button on the left." : "כדאי לנסות לערוך את השאילתה או להוסיף שאילתה בעזרת הכםתור שמימין.",
     "Select one or more tags" : "יש לבחור תגית אחת או יותר",
+    "New bookmark" : "סימנייה חדשה",
     "New folder" : "תיקייה חדשה",
     "Grid view" : "תצוגת טבלה",
     "List view" : "תצוגת רשימה",
     "Move selection" : "העברת בחירה",
     "Delete selection" : "מחיקת בחירה",
+    "Open all selected" : "לפתוח את כל הנבחרים",
+    "Select all visible" : "בחירת כל הגלויות",
+    "Cancel selection" : "ביטול בחירה",
+    "Selected {folders} folders and {bookmarks} bookmarks" : "נבחרו {folders} תיקיות ו־{bookmarks} סימניות",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["סימנייה אחת נבחרה","%n סימניות נבחרו","%n סימניות נבחרו","%n סימניות נבחרו"],
+    "_Selected %n folder_::_Selected %n folders_" : ["נבחרה תיקייה %n","נבחרו %n תיקיות","נבחרו %n תיקיות","נבחרו %n תיקיות"],
     "Enter a link" : "נא למלא קישור",
     "Create" : "יצירה",
     "Cancel" : "ביטול",
     "Enter folder title" : "נא למלא כותרת לתיקייה",
+    "Select folder" : "בחירת תיקייה",
+    "Shared by {user}" : "שותפה על ידי {user}",
+    "Shared privately" : "שותפה בפרטיות",
     "Public" : "ציבורי",
     "Root folder" : "תיקיית בסיס",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["תיקייה אחת ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות"],
@@ -34,6 +44,7 @@ OC.L10N.register(
     "All Bookmarks" : "כל הסימניות",
     "Recent Bookmarks" : "סימניות אחרונות",
     "Untagged" : "ללא תגית",
+    "{used} bookmarks of {available} available" : "{used} סימניות מתוך {available} זמינות",
     "Import" : "ייבוא",
     "Export" : "ייצוא",
     "Sorting" : "מיון",
@@ -63,7 +74,11 @@ OC.L10N.register(
     "Select a user or group" : "נא לבחור משתמש או קבוצה",
     "Share link" : "קישור שיתוף",
     "Copy link" : "העתקת קישור",
+    "Delete link" : "מחיקת קישור",
+    "Create public link" : "יצירת קישור ציבורי",
     "Allow editing" : "לאפשר עריכה",
+    "Allow sharing" : "לאפשר שיתוף",
+    "Remove share" : "הסרת שיתוף",
     "Link copied" : "הקישור הועתק",
     "Select" : "בחירה",
     "Previews" : "תצוגות מקדימות",
@@ -85,6 +100,7 @@ OC.L10N.register(
     "Title" : "תפקיד",
     "Link" : "קישור",
     "Enter bookmark URL" : "נא למלא כתובת סימנייה",
+    "Folder" : "תיקייה",
     "Failed to find existing bookmark" : "איתור סימנייה קיימת נכשל",
     "Failed to create bookmark" : "יצירת סימנייה נכשלה",
     "Failed to save bookmark" : "שמירת סימנייה נכשלה",
@@ -98,6 +114,9 @@ OC.L10N.register(
     "Failed to delete parts of selection" : "מחיקת חלקים מהבחירה נכשלה",
     "Failed to fetch bookmarks." : "קבלת הסימניות נכשלה.",
     "Failed to change setting" : "שינוי ההגדרות נכשל",
+    "Failed to load setting {key}" : "טעינת ההגדרה {key} נכשלה",
+    "Failed to update share {shareId}" : "עדכון השיתוף {shareId} נכשל",
+    "Failed to delete share {shareId}" : "מחיקת השיתוף {shareId} נכשלה",
     "Bookmarks feed" : "ערוץ סימניות"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
