@@ -28,6 +28,7 @@ OC.L10N.register(
     "Select" : "Select",
     "Privacy" : "Confindențialitate",
     "Title" : "Titlu",
-    "Link" : "Legătură"
+    "Link" : "Legătură",
+    "Folder" : "Director"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
