@@ -17,6 +17,7 @@ OC.L10N.register(
     "Share link" : "Share link",
     "Select" : "Select",
     "Title" : "මාතෘකාව",
-    "Link" : "Link"
+    "Link" : "Link",
+    "Folder" : "ෆෝල්ඩරය"
 },
 "nplurals=2; plural=(n != 1);");
