@@ -27,6 +27,7 @@ OC.L10N.register(
     "Select" : "Select",
     "Privacy" : "Privatnost",
     "Title" : "Naslov",
-    "Link" : "Prečica"
+    "Link" : "Prečica",
+    "Folder" : "Folder"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
